@@ -1,10 +1,12 @@
 #!/bin/sh
-#
+
 # Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
+# SPDX-License-Identifier: MPL-2.0
+#
 # This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+# License, v. 2.0.  If a copy of the MPL was not distributed with this
+# file, you can obtain one at https://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
@@ -26,7 +28,6 @@ rm -f ./ns2/inline.db.jbk
 rm -f ./ns2/inline.db.signed
 rm -f ./ns2/inlinesec.bk*
 rm -rf ./ns2/new-zones
-rm -f ./ns*/named.lock
 rm -f ./ns*/named.run ./ns*/named.run.prev
 rm -f ./ns2/nzf-*
 rm -f ./ns3/named.conf
