@@ -12,9 +12,12 @@
 from . import check
 from . import instance
 from . import query
+from . import name
 from . import rndc
 from . import run
 from . import log
+from . import vars  # pylint: disable=redefined-builtin
+from . import hypothesis
 
 # isctest.mark module is intentionally NOT imported, because it relies on
 # environment variables which might not be set at the time of import of the
