@@ -9,16 +9,9 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-import logging
-
-from . import log
-from .vars import ALL, init_vars
+from .vars import ALL
 
 
 if __name__ == "__main__":
-    # use root logger as fallback - we're not interested in proper logs here
-    log.basic.LOGGERS["conftest"] = logging.getLogger()
-
-    init_vars()
     for name, value in ALL.items():
         print(f"export {name}={value}")
