@@ -11,21 +11,22 @@
  * information regarding copyright ownership.
  */
 
-#ifndef RDATA_GENERIC_L64_106_C
-#define RDATA_GENERIC_L64_106_C
+#ifndef RDATA_GENERIC_L32_105_C
+#define RDATA_GENERIC_L32_105_C
 
 #include <string.h>
 
 #include <isc/net.h>
 
-#define RRTYPE_L64_ATTRIBUTES (0)
+#define RRTYPE_L32_ATTRIBUTES (0)
 
 static isc_result_t
-fromtext_l64(ARGS_FROMTEXT) {
+fromtext_l32(ARGS_FROMTEXT) {
 	isc_token_t token;
-	unsigned char locator[NS_LOCATORSZ];
+	struct in_addr addr;
+	isc_region_t region;
 
-	REQUIRE(type == dns_rdatatype_l64);
+	REQUIRE(type == dns_rdatatype_l32);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -43,20 +44,26 @@ fromtext_l64(ARGS_FROMTEXT) {
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
 				      false));
 
-	if (locator_pton(DNS_AS_STR(token), locator) != 1) {
-		RETTOK(DNS_R_SYNTAX);
+	if (inet_pton(AF_INET, DNS_AS_STR(token), &addr) != 1) {
+		RETTOK(DNS_R_BADDOTTEDQUAD);
 	}
-	return (mem_tobuffer(target, locator, NS_LOCATORSZ));
+	isc_buffer_availableregion(target, &region);
+	if (region.length < 4) {
+		return (ISC_R_NOSPACE);
+	}
+	memmove(region.base, &addr, 4);
+	isc_buffer_add(target, 4);
+	return (ISC_R_SUCCESS);
 }
 
 static isc_result_t
-totext_l64(ARGS_TOTEXT) {
+totext_l32(ARGS_TOTEXT) {
 	isc_region_t region;
-	char buf[sizeof("xxxx:xxxx:xxxx:xxxx")];
+	char buf[sizeof("65000")];
 	unsigned short num;
 
-	REQUIRE(rdata->type == dns_rdatatype_l64);
-	REQUIRE(rdata->length == 10);
+	REQUIRE(rdata->type == dns_rdatatype_l32);
+	REQUIRE(rdata->length == 6);
 
 	UNUSED(tctx);
 
@@ -68,26 +75,21 @@ totext_l64(ARGS_TOTEXT) {
 
 	RETERR(str_totext(" ", target));
 
-	snprintf(buf, sizeof(buf), "%x:%x:%x:%x",
-		 region.base[0] << 8 | region.base[1],
-		 region.base[2] << 8 | region.base[3],
-		 region.base[4] << 8 | region.base[5],
-		 region.base[6] << 8 | region.base[7]);
-	return (str_totext(buf, target));
+	return (inet_totext(AF_INET, tctx->flags, &region, target));
 }
 
 static isc_result_t
-fromwire_l64(ARGS_FROMWIRE) {
+fromwire_l32(ARGS_FROMWIRE) {
 	isc_region_t sregion;
 
-	REQUIRE(type == dns_rdatatype_l64);
+	REQUIRE(type == dns_rdatatype_l32);
 
 	UNUSED(type);
 	UNUSED(rdclass);
 	UNUSED(dctx);
 
 	isc_buffer_activeregion(source, &sregion);
-	if (sregion.length != 10) {
+	if (sregion.length != 6) {
 		return (DNS_R_FORMERR);
 	}
 	isc_buffer_forward(source, sregion.length);
@@ -95,9 +97,9 @@ fromwire_l64(ARGS_FROMWIRE) {
 }
 
 static isc_result_t
-towire_l64(ARGS_TOWIRE) {
-	REQUIRE(rdata->type == dns_rdatatype_l64);
-	REQUIRE(rdata->length == 10);
+towire_l32(ARGS_TOWIRE) {
+	REQUIRE(rdata->type == dns_rdatatype_l32);
+	REQUIRE(rdata->length == 6);
 
 	UNUSED(cctx);
 
@@ -105,15 +107,15 @@ towire_l64(ARGS_TOWIRE) {
 }
 
 static int
-compare_l64(ARGS_COMPARE) {
+compare_l32(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == dns_rdatatype_l64);
-	REQUIRE(rdata1->length == 10);
-	REQUIRE(rdata2->length == 10);
+	REQUIRE(rdata1->type == dns_rdatatype_l32);
+	REQUIRE(rdata1->length == 6);
+	REQUIRE(rdata2->length == 6);
 
 	dns_rdata_toregion(rdata1, &region1);
 	dns_rdata_toregion(rdata2, &region2);
@@ -121,56 +123,60 @@ compare_l64(ARGS_COMPARE) {
 }
 
 static isc_result_t
-fromstruct_l64(ARGS_FROMSTRUCT) {
-	dns_rdata_l64_t *l64 = source;
+fromstruct_l32(ARGS_FROMSTRUCT) {
+	dns_rdata_l32_t *l32 = source;
+	uint32_t n;
 
-	REQUIRE(type == dns_rdatatype_l64);
-	REQUIRE(l64 != NULL);
-	REQUIRE(l64->common.rdtype == type);
-	REQUIRE(l64->common.rdclass == rdclass);
+	REQUIRE(type == dns_rdatatype_l32);
+	REQUIRE(l32 != NULL);
+	REQUIRE(l32->common.rdtype == type);
+	REQUIRE(l32->common.rdclass == rdclass);
 
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	RETERR(uint16_tobuffer(l64->pref, target));
-	return (mem_tobuffer(target, l64->l64, sizeof(l64->l64)));
+	RETERR(uint16_tobuffer(l32->pref, target));
+	n = ntohl(l32->l32.s_addr);
+	return (uint32_tobuffer(n, target));
 }
 
 static isc_result_t
-tostruct_l64(ARGS_TOSTRUCT) {
+tostruct_l32(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_l64_t *l64 = target;
+	dns_rdata_l32_t *l32 = target;
+	uint32_t n;
 
-	REQUIRE(rdata->type == dns_rdatatype_l64);
-	REQUIRE(l64 != NULL);
-	REQUIRE(rdata->length == 10);
+	REQUIRE(rdata->type == dns_rdatatype_l32);
+	REQUIRE(l32 != NULL);
+	REQUIRE(rdata->length == 6);
 
 	UNUSED(mctx);
 
-	l64->common.rdclass = rdata->rdclass;
-	l64->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&l64->common, link);
+	l32->common.rdclass = rdata->rdclass;
+	l32->common.rdtype = rdata->type;
+	ISC_LINK_INIT(&l32->common, link);
 
 	dns_rdata_toregion(rdata, &region);
-	l64->pref = uint16_fromregion(&region);
-	memmove(l64->l64, region.base, region.length);
+	l32->pref = uint16_fromregion(&region);
+	n = uint32_fromregion(&region);
+	l32->l32.s_addr = htonl(n);
 	return (ISC_R_SUCCESS);
 }
 
 static void
-freestruct_l64(ARGS_FREESTRUCT) {
-	dns_rdata_l64_t *l64 = source;
+freestruct_l32(ARGS_FREESTRUCT) {
+	dns_rdata_l32_t *l32 = source;
 
-	REQUIRE(l64 != NULL);
-	REQUIRE(l64->common.rdtype == dns_rdatatype_l64);
+	REQUIRE(l32 != NULL);
+	REQUIRE(l32->common.rdtype == dns_rdatatype_l32);
 
 	return;
 }
 
 static isc_result_t
-additionaldata_l64(ARGS_ADDLDATA) {
-	REQUIRE(rdata->type == dns_rdatatype_l64);
-	REQUIRE(rdata->length == 10);
+additionaldata_l32(ARGS_ADDLDATA) {
+	REQUIRE(rdata->type == dns_rdatatype_l32);
+	REQUIRE(rdata->length == 6);
 
 	UNUSED(rdata);
 	UNUSED(owner);
@@ -181,11 +187,11 @@ additionaldata_l64(ARGS_ADDLDATA) {
 }
 
 static isc_result_t
-digest_l64(ARGS_DIGEST) {
+digest_l32(ARGS_DIGEST) {
 	isc_region_t r;
 
-	REQUIRE(rdata->type == dns_rdatatype_l64);
-	REQUIRE(rdata->length == 10);
+	REQUIRE(rdata->type == dns_rdatatype_l32);
+	REQUIRE(rdata->length == 6);
 
 	dns_rdata_toregion(rdata, &r);
 
@@ -193,8 +199,8 @@ digest_l64(ARGS_DIGEST) {
 }
 
 static bool
-checkowner_l64(ARGS_CHECKOWNER) {
-	REQUIRE(type == dns_rdatatype_l64);
+checkowner_l32(ARGS_CHECKOWNER) {
+	REQUIRE(type == dns_rdatatype_l32);
 
 	UNUSED(name);
 	UNUSED(type);
@@ -205,9 +211,9 @@ checkowner_l64(ARGS_CHECKOWNER) {
 }
 
 static bool
-checknames_l64(ARGS_CHECKNAMES) {
-	REQUIRE(rdata->type == dns_rdatatype_l64);
-	REQUIRE(rdata->length == 10);
+checknames_l32(ARGS_CHECKNAMES) {
+	REQUIRE(rdata->type == dns_rdatatype_l32);
+	REQUIRE(rdata->length == 6);
 
 	UNUSED(rdata);
 	UNUSED(owner);
@@ -217,8 +223,8 @@ checknames_l64(ARGS_CHECKNAMES) {
 }
 
 static int
-casecompare_l64(ARGS_COMPARE) {
-	return (compare_l64(rdata1, rdata2));
+casecompare_l32(ARGS_COMPARE) {
+	return (compare_l32(rdata1, rdata2));
 }
 
-#endif /* RDATA_GENERIC_L64_106_C */
+#endif /* RDATA_GENERIC_L32_105_C */
