@@ -23,7 +23,13 @@
 #include <isc/result.h> /* for ISC_R_ codes */
 #include <isc/util.h>
 
+#if ISC_MUTEX_ERROR_CHECK && defined(PTHREAD_ERRORCHECK_MUTEX_INITIALIZER_NP)
+#define ISC_MUTEX_INITIALIZER PTHREAD_ERRORCHECK_MUTEX_INITIALIZER_NP
+#elif defined(PTHREAD_ADAPTIVE_MUTEX_INITIALIZER_NP)
+#define ISC_MUTEX_INITIALIZER PTHREAD_ADAPTIVE_MUTEX_INITIALIZER_NP
+#else
 #define ISC_MUTEX_INITIALIZER PTHREAD_MUTEX_INITIALIZER
+#endif
 
 ISC_LANG_BEGINDECLS
 
