@@ -45,6 +45,8 @@
 
 #define TLS_MAX_SEND_BUF_SIZE (UINT16_MAX + UINT16_MAX / 2)
 
+#define MAX_DNS_MESSAGE_SIZE (UINT16_MAX)
+
 #ifdef ISC_NETMGR_TRACE
 ISC_ATTR_UNUSED static const char *
 tls_status2str(int tls_status) {
@@ -608,27 +610,34 @@ tls_do_bio(isc_nmsocket_t *sock, isc_region_t *received_data,
 				  SSL_SENT_SHUTDOWN) != 0);
 			bool write_failed = false;
 			if (*(uint16_t *)send_data->tcplen != 0) {
+				size_t sendlen = 0;
+				uint8_t sendbuf[MAX_DNS_MESSAGE_SIZE +
+						sizeof(uint16_t)];
 				/*
 				 * There is a DNS message length to write - do
 				 * it.
 				 */
-				rv = SSL_write_ex(
-					sock->tlsstream.tls, send_data->tcplen,
-					sizeof(send_data->tcplen), &len);
-				if (rv != 1 || len != sizeof(send_data->tcplen))
-				{
+
+				/*
+				 * There's no SSL_writev(), so we need to use a
+				 * local buffer to assemble the whole message
+				 */
+				INSIST(send_data->uvbuf.len <=
+				       MAX_DNS_MESSAGE_SIZE);
+
+				sendlen = send_data->uvbuf.len +
+					  sizeof(uint16_t);
+				memmove(sendbuf, send_data->tcplen,
+					sizeof(uint16_t));
+				memmove(sendbuf + sizeof(uint16_t),
+					send_data->uvbuf.base,
+					send_data->uvbuf.len);
+
+				/* Write data */
+				rv = SSL_write_ex(sock->tlsstream.tls, sendbuf,
+						  sendlen, &len);
+				if (rv != 1 || len != sendlen) {
 					write_failed = true;
-				} else {
-					/* Write data */
-					rv = SSL_write_ex(sock->tlsstream.tls,
-							  send_data->uvbuf.base,
-							  send_data->uvbuf.len,
-							  &len);
-					if (rv != 1 ||
-					    len != send_data->uvbuf.len)
-					{
-						write_failed = true;
-					}
 				}
 			} else {
 				/* Write data only */
@@ -904,7 +913,7 @@ tlslisten_acceptcb(isc_nmhandle_t *handle, isc_result_t result, void *cbarg) {
 	/*
 	 * We need to create a 'wrapper' tlssocket for this connection.
 	 */
-	tlssock = isc_mem_get(handle->sock->worker->mctx, sizeof(*tlssock));
+	tlssock = isc_mempool_get(handle->sock->worker->nmsocket_pool);
 	isc__nmsocket_init(tlssock, handle->sock->worker, isc_nm_tlssocket,
 			   &local, NULL);
 
@@ -969,8 +978,7 @@ isc_nm_listentls(isc_nm_t *mgr, uint32_t workers, isc_sockaddr_t *iface,
 	}
 	REQUIRE(workers <= mgr->nloops);
 
-	tlssock = isc_mem_get(worker->mctx, sizeof(*tlssock));
-
+	tlssock = isc_mempool_get(worker->nmsocket_pool);
 	isc__nmsocket_init(tlssock, worker, isc_nm_tlslistener, iface, NULL);
 	tlssock->accept_cb = accept_cb;
 	tlssock->accept_cbarg = accept_cbarg;
@@ -1204,7 +1212,7 @@ isc_nm_tlsconnect(isc_nm_t *mgr, isc_sockaddr_t *local, isc_sockaddr_t *peer,
 		return;
 	}
 
-	sock = isc_mem_get(worker->mctx, sizeof(*sock));
+	sock = isc_mempool_get(worker->nmsocket_pool);
 	isc__nmsocket_init(sock, worker, isc_nm_tlssocket, local, NULL);
 	sock->connect_cb = connect_cb;
 	sock->connect_cbarg = connect_cbarg;
