@@ -85,9 +85,7 @@ isc_stdio_read(void *ptr, size_t size, size_t nmemb, FILE *f, size_t *nret) {
 			result = isc__errno2result(errno);
 		}
 	}
-	if (nret != NULL) {
-		*nret = r;
-	}
+	SET_IF_NOT_NULL(nret, r);
 	return (result);
 }
 
@@ -102,9 +100,7 @@ isc_stdio_write(const void *ptr, size_t size, size_t nmemb, FILE *f,
 	if (r != nmemb) {
 		result = isc__errno2result(errno);
 	}
-	if (nret != NULL) {
-		*nret = r;
-	}
+	SET_IF_NOT_NULL(nret, r);
 	return (result);
 }
 
