@@ -520,7 +520,8 @@ struct check_qpchain {
 };
 
 static void
-check_qpchain(dns_qp_t *qp, struct check_qpchain check[]) {
+check_qpchainiter(dns_qp_t *qp, struct check_qpchain check[],
+		  dns_qpiter_t *iter) {
 	for (int i = 0; check[i].query != NULL; i++) {
 		isc_result_t result;
 		dns_fixedname_t fn1;
@@ -529,9 +530,8 @@ check_qpchain(dns_qp_t *qp, struct check_qpchain check[]) {
 
 		dns_qpchain_init(qp, &chain);
 		dns_test_namefromstring(check[i].query, &fn1);
-		result = dns_qp_lookup(qp, name, NULL, NULL, &chain, NULL,
+		result = dns_qp_lookup(qp, name, NULL, iter, &chain, NULL,
 				       NULL);
-
 #if 0
 		fprintf(stderr, "%s %s (expected %s), "
 			"len %d (expected %d)\n", check[i].query,
@@ -539,13 +539,13 @@ check_qpchain(dns_qp_t *qp, struct check_qpchain check[]) {
 			isc_result_totext(check[i].result),
 			dns_qpchain_length(&chain), check[i].length);
 #endif
+
 		assert_int_equal(result, check[i].result);
 		assert_int_equal(dns_qpchain_length(&chain), check[i].length);
 		for (unsigned int j = 0; j < check[i].length; j++) {
 			dns_fixedname_t fn2, fn3;
 			dns_name_t *expected = dns_fixedname_initname(&fn2);
 			dns_name_t *found = dns_fixedname_initname(&fn3);
-
 			dns_test_namefromstring(check[i].names[j], &fn2);
 			dns_qpchain_node(&chain, j, found, NULL, NULL);
 #if 0
@@ -559,6 +559,14 @@ check_qpchain(dns_qp_t *qp, struct check_qpchain check[]) {
 	}
 }
 
+static void
+check_qpchain(dns_qp_t *qp, struct check_qpchain check[]) {
+	dns_qpiter_t iter;
+	dns_qpiter_init(qp, &iter);
+	check_qpchainiter(qp, check, NULL);
+	check_qpchainiter(qp, check, &iter);
+}
+
 ISC_RUN_TEST_IMPL(qpchain) {
 	dns_qp_t *qp = NULL;
 	const char insert[][16] = { ".",      "a.",	    "b.",
@@ -592,6 +600,24 @@ ISC_RUN_TEST_IMPL(qpchain) {
 
 	check_qpchain(qp, check1);
 	dns_qp_destroy(&qp);
+
+	const char insert2[][16] = { "a.", "d.b.a.", "z.d.b.a.", "" };
+
+	i = 0;
+
+	dns_qp_create(mctx, &string_methods, NULL, &qp);
+
+	while (insert2[i][0] != '\0') {
+		insert_str(qp, insert2[i++]);
+	}
+
+	static struct check_qpchain check2[] = {
+		{ "f.c.b.a.", DNS_R_PARTIALMATCH, 1, { "a." } },
+		{ NULL, 0, 0, { NULL } },
+	};
+
+	check_qpchain(qp, check2);
+	dns_qp_destroy(&qp);
 }
 
 struct check_predecessors {
@@ -602,7 +628,8 @@ struct check_predecessors {
 };
 
 static void
-check_predecessors(dns_qp_t *qp, struct check_predecessors check[]) {
+check_predecessors_withchain(dns_qp_t *qp, struct check_predecessors check[],
+			     dns_qpchain_t *chain) {
 	isc_result_t result;
 	dns_fixedname_t fn1, fn2;
 	dns_name_t *name = dns_fixedname_initname(&fn1);
@@ -626,7 +653,7 @@ check_predecessors(dns_qp_t *qp, struct check_predecessors check[]) {
 		result = dns_name_tostring(expred, &predstr, mctx);
 		assert_int_equal(result, ISC_R_SUCCESS);
 
-		result = dns_qp_lookup(qp, name, NULL, &it, NULL, NULL, NULL);
+		result = dns_qp_lookup(qp, name, NULL, &it, chain, NULL, NULL);
 #if 0
 		fprintf(stderr, "%s: expected %s got %s\n", check[i].query,
 			isc_result_totext(check[i].result),
@@ -685,6 +712,14 @@ check_predecessors(dns_qp_t *qp, struct check_predecessors check[]) {
 	}
 }
 
+static void
+check_predecessors(dns_qp_t *qp, struct check_predecessors check[]) {
+	dns_qpchain_t chain;
+	dns_qpchain_init(qp, &chain);
+	check_predecessors_withchain(qp, check, NULL);
+	check_predecessors_withchain(qp, check, &chain);
+}
+
 ISC_RUN_TEST_IMPL(predecessors) {
 	dns_qp_t *qp = NULL;
 	const char insert[][16] = {
@@ -818,6 +853,8 @@ ISC_RUN_TEST_IMPL(fixiterator) {
 
 	static struct check_predecessors check1[] = {
 		{ "newtext.dynamic.", "mx.dynamic.", DNS_R_PARTIALMATCH, 7 },
+		{ "nsd.dynamic.", "ns.dynamic.", DNS_R_PARTIALMATCH, 6 },
+		{ "nsf.dynamic.", "nsec.dynamic.", DNS_R_PARTIALMATCH, 5 },
 		{ "d.", "trailing.", ISC_R_NOTFOUND, 0 },
 		{ "absent.", "trailing.", ISC_R_NOTFOUND, 0 },
 		{ "nonexistent.", "txt.dynamic.", ISC_R_NOTFOUND, 1 },
