@@ -21,7 +21,6 @@
 #include <cmocka.h>
 
 #include <isc/buffer.h>
-#include <isc/lib.h>
 #include <isc/mem.h>
 #include <isc/os.h>
 #include <isc/proxy2.h>
@@ -69,7 +68,7 @@ dummy_subtlv_iter_cb(const uint8_t client, const bool client_cert_verified,
 		break;
 	};
 
-	return true;
+	return (true);
 }
 
 static bool
@@ -93,7 +92,7 @@ dummy_tlv_iter_cb(const isc_proxy2_tlv_type_t tlv_type,
 
 		assert_true(result == ISC_R_SUCCESS);
 	}
-	return true;
+	return (true);
 }
 
 static void
@@ -146,16 +145,15 @@ proxy2_handler_dummy(const isc_result_t result, const isc_proxy2_command_t cmd,
 static int
 setup_test_proxy(void **state) {
 	isc_proxy2_handler_t **handler = (isc_proxy2_handler_t **)state;
-	*handler = isc_proxy2_handler_new(isc_g_mctx, 0, proxy2_handler_dummy,
-					  NULL);
-	return 0;
+	*handler = isc_proxy2_handler_new(mctx, 0, proxy2_handler_dummy, NULL);
+	return (0);
 }
 
 static int
 teardown_test_proxy(void **state) {
 	isc_proxy2_handler_free((isc_proxy2_handler_t **)state);
 
-	return 0;
+	return (0);
 }
 
 static void
@@ -532,7 +530,7 @@ ISC_RUN_TEST_IMPL(proxyheader_max_size_test) {
 
 	UNUSED(state);
 
-	isc_proxy2_handler_init(&handler, isc_g_mctx, sizeof(proxy_v2_header),
+	isc_proxy2_handler_init(&handler, mctx, sizeof(proxy_v2_header),
 				proxy2_handler_dummy, NULL);
 
 	result = isc_proxy2_handler_push_data(&handler, proxy_v2_header,
@@ -542,8 +540,7 @@ ISC_RUN_TEST_IMPL(proxyheader_max_size_test) {
 
 	isc_proxy2_handler_uninit(&handler);
 
-	isc_proxy2_handler_init(&handler, isc_g_mctx,
-				sizeof(proxy_v2_header) - 1,
+	isc_proxy2_handler_init(&handler, mctx, sizeof(proxy_v2_header) - 1,
 				proxy2_handler_dummy, NULL);
 
 	result = isc_proxy2_handler_push_data(&handler, proxy_v2_header,
@@ -717,7 +714,7 @@ rebuild_subtlv_iter_cb(const uint8_t client, const bool client_cert_verified,
 	result = isc_proxy2_append_tlv(outbuf, tls_subtlv_type, data);
 	assert_true(result == ISC_R_SUCCESS);
 
-	return true;
+	return (true);
 }
 
 static bool
@@ -759,7 +756,7 @@ rebuild_tlv_iter_cb(const isc_proxy2_tlv_type_t tlv_type,
 		assert_true(result == ISC_R_SUCCESS);
 	}
 
-	return true;
+	return (true);
 }
 
 static void
@@ -796,8 +793,8 @@ proxy2_handler_rebuild(isc_buffer_t *restrict outbuf, const void *data,
 		       const size_t size) {
 	isc_proxy2_handler_t handler = { 0 };
 
-	isc_proxy2_handler_init(&handler, isc_g_mctx, 0,
-				proxy2_handler_rebuild_cb, outbuf);
+	isc_proxy2_handler_init(&handler, mctx, 0, proxy2_handler_rebuild_cb,
+				outbuf);
 
 	isc_proxy2_handler_push_data(&handler, data, size);
 
